# Authors

- Cyril Novel <https://www.twitter.com/CrlNvl>
- Trey Hunner <http://treyhunner.com> (*names* Python package)
- Simeon Visser <http://simeonvisser.com> (*names* Python package)

Les données INSEE ont été extraites par Julien Dubedout, merci à lui.
